# stay on the xpath

some nice simple wrappers around the excellent libxml2 library

to get this working on macos, you may need to install the deve libraries for Majave

[Mojave gcc includes for build](https://silvae86.github.io/sysadmin/mac/osx/mojave/beta/libxml2/2018/07/05/fixing-missing-headers-for-homebrew-in-mac-osx-mojave/)

## xget.py

gets xpath values from the command line

## xset.py

sets xpath values from the command line



